#include "test.h"

int print_file(xml_row_st *myrow)
{
  xml_row_field_st *row_ptr;
  printf("*************************************************\n");

  while ((row_ptr= xml_row_read(myrow)))
  {
    printf("Fields %u\n", myrow->fields);
    for (; row_ptr; row_ptr= row_ptr->next) 
    {
      printf("%.*s\t", (int)row_ptr->length, row_ptr->str);
    }
    printf("\n");
  }

  return 0;
}


xmlrow_return create_row(void *not_used)
{
  xml_row_st myrow;

  xml_row_create(&myrow);

  xml_row_close(&myrow);

  return XMLROW_SUCCESS;
}

xmlrow_return reset_row(void *not_used)
{
  xml_row_st myrow;

  xml_row_create(&myrow);

  xml_row_reset(&myrow);

  xml_row_close(&myrow);

  return XMLROW_SUCCESS;
}

xmlrow_return populate_row(void *not_used)
{
  xml_row_st myrow;
  char col_name[16];
  char col_value[32];
  unsigned int seed;
  unsigned int x, j;

  xml_row_create(&myrow);

  for (x= 0; x <1024; x++) 
  {
    snprintf(col_name, 16, "Col%d", x);
    seed= x;

    for (j= 0; j < 32; j++)
      col_value[j] = (char) (rand_r(&seed) % 26 + 'A');

    col_value[31] = '\0';
    xml_row_field_add(&myrow, col_name, col_value, strlen(col_value), 0);
  }

  xml_row_close(&myrow);

  return XMLROW_SUCCESS;
}

xmlrow_return populate_with_null(void *not_used)
{
  return XMLROW_SUCCESS;
}

xmlrow_return serialize_row(void *not_used)
{
  xml_row_st myrow, *ptr;
  char *string;
  size_t length;

  ptr= xml_row_create(&myrow);
  assert(ptr);

  xml_row_field_add(&myrow, "col1", "Sample row", strlen("Sample row"), 0);
  string= xml_row_serialize(&myrow, &length);
  /* return of xml_row_serialize is BS */
  assert(length == 136);
  printf("XML ROW\n%s\n", string);
  xml_row_set(&myrow, string, length);
  string= xml_row_serialize(&myrow, &length);
  printf("XML ROW\n%s\n", string);

  xml_row_close(&myrow);

  return XMLROW_SUCCESS;
}

test_st tests[] ={
  {"create_row", 0, create_row },
  {"reset_row", 0, reset_row },
  {"serialize_row", 0, serialize_row  },
  {"populate_with_null", 0, serialize_row  },
  {0, 0, 0}
};


collection_st collection[] ={
  {"basic", 0, 0, tests},
  {0, 0, 0, 0}
};

collection_st *gets_collections(void)
{
  return collection;
}
