/*
  Sample test application.
*/
#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <time.h>

#include "test.h"

long int timedif(struct timeval a, struct timeval b)
{
  register int us, s;

  us = a.tv_usec - b.tv_usec;
  us /= 1000;
  s = a.tv_sec - b.tv_sec;
  s *= 1000;
  return s + us;
}

int main(int argc, char *argv[])
{
  unsigned int x;
  char *collection_to_run= NULL;
  char *wildcard= NULL;
  collection_st *collection;

  collection= gets_collections();

  if (argc > 1)
    collection_to_run= argv[1];

  if (argc == 3)
    wildcard= argv[2];

  srandom(time(NULL));

  collection_st *next;
  for (next= collection; next->name; next++)
  {
    test_st *run;

    run= next->tests;
    if (collection_to_run && strcmp(collection_to_run, next->name))
      continue;

    fprintf(stderr, "\n%s\n\n", next->name);

    for (x= 0; run->name; run++)
    {
      if (wildcard && strcmp(wildcard, run->name))
        continue;

      fprintf(stderr, "Testing %s", run->name);

      struct timeval start_time, end_time;

      if (next->pre)
      {
        xmlrow_return rc;

        if (next->pre)
          rc= next->pre(NULL);

        if (rc != XMLROW_SUCCESS)
        {
          fprintf(stderr, "\t\t\t\t\t [ skipping ]\n");
          continue;
        }
      }

      gettimeofday(&start_time, NULL);
      run->function(NULL);
      gettimeofday(&end_time, NULL);
      long int load_time= timedif(end_time, start_time);
      fprintf(stderr, "\t\t\t\t\t %ld.%03ld [ ok ]\n", load_time / 1000, 
              load_time % 1000);

      if (next->post)
        (void)next->post(NULL);

    }
  }

  fprintf(stderr, "All tests completed successfully\n\n");

  return 0;
}
